import React from 'react';
import { TextStyle } from 'react-native';
/**
 * Props for the HighlightText component
 */
export interface HighlightTextProps {
    /**
     * Base style for the text
     */
    style?: TextStyle;
    /**
     * Style applied to the highlighted portions of text
     */
    highlightStyle?: TextStyle;
    /**
     * The string to search for and highlight
     */
    queryString: string;
    /**
     * The text content to display and search within
     */
    text: string;
}
/**
 * A component that highlights occurrences of a search string within text.
 *
 * @example
 * ```tsx
 * <HighlightText
 *   text="This is a sample text"
 *   queryString="sample"
 *   highlightStyle={{ backgroundColor: 'yellow' }}
 * />
 * ```
 */
export declare const HighlightText: React.FC<HighlightTextProps>;
