"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HighlightText = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
/**
 * A component that highlights occurrences of a search string within text.
 *
 * @example
 * ```tsx
 * <HighlightText
 *   text="This is a sample text"
 *   queryString="sample"
 *   highlightStyle={{ backgroundColor: 'yellow' }}
 * />
 * ```
 */
const HighlightText = ({ style = {}, highlightStyle = {}, queryString, text, }) => {
    // If no search term is provided or the search term is empty,
    // return the original text
    if (!queryString || queryString.trim() === '') {
        return react_1.default.createElement(react_native_1.Text, { style: style }, text);
    }
    // Escape special characters in the search term for RegExp
    const escapedQueryString = queryString.replace(/[.*+?^${}()|[\]\\]/g, '\\$&');
    // Create a RegExp object with the search text, 'i' for case-insensitive
    const regex = new RegExp(`(${escapedQueryString})`, 'i');
    // Split the text based on the search term
    const parts = text.split(regex);
    return (react_1.default.createElement(react_native_1.Text, { style: style }, parts.map((part, index) => {
        // Check if the current part matches the search term (case-insensitive)
        const isHighlighted = part.toLowerCase() === queryString.toLowerCase();
        return (react_1.default.createElement(react_native_1.Text, { key: index, style: isHighlighted ? [style, highlightStyle] : style }, part));
    })));
};
exports.HighlightText = HighlightText;
